import axios from 'axios';
import { ElMessageBox, ElMessage } from 'element-plus';
import { getAuthHeaders } from '@/utils/auth';
import { logout } from '@/store/useCurrentUser';

const service = axios.create({
  baseURL: import.meta.env.VITE_BASE_API,
  timeout: 60 * 1000,
});
let logouted = 0;
service.interceptors.request.use(
  (config) => {
    config.headers = { ...config.headers, ...getAuthHeaders() };
    return config;
  },
  (error) => Promise.reject(error),
);

service.interceptors.response.use(
  (res) => {
    const { message, status, code, msg } = res.data;
    if (status) {
      if (status === 200) {
        return res;
      }

      ElMessage.error(message);
    } else if (code === 401) {
      // 账号互踢
      if (!logouted) {
        ElMessageBox.alert(msg.includes('顶') ? '您的账号已在其他设备登录，您已被迫下线！' : '登录过期，请重新登录！', {
          confirmButtonText: '重新登录',
          type: 'warning',
          closeOnClickModal: false,
          showClose: false,
        }).then(() => {
          // 未登录
          logout();
        });
        logouted = 1;
      }
    } else {
      return res;
    }
  },
  (e) => {
    const {
      response: {
        data: { message, error },
        status,
      },
    } = e;
    if (status === 401) {
      logouted ||
        ElMessageBox.alert('登录状态已过期，请重新登录', { confirmButtonText: '重新登录', type: 'warning', closeOnClickModal: false, showClose: false }).then(() => {
          // 未登录
          logout();
        });
      logouted = 1;
    } else if (message) {
      ElMessage.error(message);
    }
    return Promise.reject(error);
  },
);

export default service;
